
clearvars -except y
clear all
clc
tic
qin=[20:-0.25:18]/3600;
Vo_in=0.4;%[0.4:0.0125:0.6];
Lsw=1.7;Ro=0.05;Ri=0.025;p2=[Lsw;Ro;Ri];
Lsw_DW=1.7;Ro_DW=0.05;Ri_DW=0.043;p3=[Lsw_DW;Ro_DW;Ri_DW];

element='l';

x=zeros(length(qin),length(Vo_in),21);
comp=zeros(length(qin),length(Vo_in),6);
exitflag=zeros(length(qin),length(Vo_in));
Cost=zeros(length(qin),length(Vo_in));
options =...
    optimset('Algorithm','interior-point','Display','off');
A=[];b=[];Aeq=[];beq=[];


%Optimization
for j=1:length(Vo_in)
    for i=1:length(qin)
        p=[qin(i);Vo_in(j)];
        % Bounds for inputs
        %The bounadries on the FSs are just to help the solver
        %and should not be active!!
        lb=[0.1;0.5;0;0.1;p2(3);zeros(16,1)];
        ub=zeros(21,1);
        ub(1:5,1)=[0.9;0.95;p3(3);0.6;p2(2)];
        for k =6:length(ub)
            a=factor(k);
            if a(1)==2; %flow
                ub(k,1)=qin(i);
            else %volume fraction
                ub(k,1)=1;
            end
        end
        %Initial guess
        if j==1 && i==1
            %  FS_g,FS_DW,rin_DW,FS_DO,rin_DO
            x01=[Vo_in(i);0.8;0.4*Ri_DW;0.3;0.65*Ro];
            x0=InitialGuess(x01,p,p2,p3);
        elseif i==1 && j~=1
            x0=x02;
        end
        [x(i,j,:),~,exitflag(i,j),output(i,j)] = fmincon(...
            @(x)CostFunc2(x,p,p2,p3),x0,A,b,Aeq,beq,lb,ub,...
            @(x)constraints2(x,p,p2,p3,element),options);
        [Cost(i,j)]=CostFunc2(x(i,j,:),p,p2,p3);
        if exitflag(i,j)==1 ||exitflag(i,j)==2
            x0=squeeze(x(i,j,:));
        end
        if j==1
            x02=x0;
        end
    end
end
Cost
y=x(:,:,15);
exitflag

toc
%% Plot
figure(6)
subplot(311);contourf(Vo_in,qin*3600,x(:,:,1))
title('Gravity Tank: Flow Split')
xlabel('\alpha_{in} [-]'); ylabel('q_{in} [m^3/h]') %set(gca,'xtick',[])%set(gca,'ytick',[])
colorbar
% optimal FS
subplot(312);contourf(Vo_in,qin*3600,x(:,:,2))
title('Dewaterer: Flow Split')
xlabel('\alpha_{in} [-]'); ylabel('q_{in} [m^3/h]')
colorbar
% optimal FS
subplot(313);contourf(Vo_in,qin*3600,x(:,:,4))
title('Deoiler: Flow Split')
xlabel('\alpha_{in} [-]'); ylabel('q_{in} [m^3/h]')
colorbar
%% Vo_in
co=lines;
figure(1)
plot(Vo_in,x(1,:,1),'Color',co(1,:),'Linewidth',2);hold on
plot(Vo_in,x(1,:,2),'Color',co(2,:),'Linewidth',2)
plot(Vo_in,x(1,:,4),'Color',co(4,:),'Linewidth',2)
xlabel('$\alpha_{in}$ [-]');ylabel('$\vec{FS}^{opt}$ [-]');
legend('$FS_G$','$FS_{DW}$','$FS_{DO}$')
figure(2)
plot(Vo_in,x(1,:,21),'Color',co(1,:),'Linewidth',2)
xlabel('$\alpha_{in}$ [-]'),ylabel('$\alpha_{L,Prod}$ [-]')
figure(3)
plot(Vo_in,x(1,:,19),'Color',co(1,:),'Linewidth',2)
xlabel('$\alpha_{in}$ [-]'),ylabel('$\alpha_{H,Prod}$ [-]')
%%
co=lines;
figure(2)
hold on
plot(Vo_in,x(1,:,21),'Color',co(2,:),'Linewidth',2)
legend('$\vec{FS^opt}$','$\vec{FS^fixed}$')
figure(3)
hold on
plot(Vo_in,x(1,:,19),'Color',co(2,:),'Linewidth',2)
legend('$\vec{FS^opt}$','$\vec{FS^fixed}$')
%% qin
co=lines;
figure(1)
plot(qin'*3600,x(:,1,1),'Color',co(1,:),'Linewidth',2);hold on
plot(qin'*3600,x(:,1,2),'Color',co(2,:),'Linewidth',2)
plot(qin'*3600,x(:,1,4),'Color',co(4,:),'Linewidth',2)
xlabel('$q_{in}$ [-]');ylabel('$\vec{FS}^{opt}$ [-]');
legend('$FS_G$','$FS_{DW}$','$FS_{DO}$')
figure(2)
plot(qin'*3600,x(:,1,21),'Color',co(1,:),'Linewidth',2)
xlabel('$q_{in}$ [-]'),ylabel('$\alpha_{L,Prod}$ [-]')
figure(3)
plot(qin'*3600,x(:,1,19),'Color',co(1,:),'Linewidth',2)
xlabel('$q_{in}$ [-]'),ylabel('$\alpha_{H,Prod}$ [-]')
%%
co=lines;
figure(2)
hold on
plot(qin'*3600,x(:,1,21),'Color',co(2,:),'Linewidth',2)
legend('$\vec{FS^opt}$','$\vec{FS^fixed}$')
figure(3)
hold on
plot(qin'*3600,x(:,1,19),'Color',co(2,:),'Linewidth',2)
legend('$\vec{FS^opt}$','$\vec{FS^fixed}$')
%% Checking smooth vt function
%uncomment vt in swirl_sep2_o. Set vt as output.
r=0:0.00001:Ro;
for i=1:length(r);
    in=[10/3600;Ro_DW;Ri_DW;0.8;4;r(i);0.8];
    vt(i)=swirl_sep2_o(0,r(i),in,element);
end
figure(2);hold on; plot(r,vt)